==> appborg-0.0.1.tgz: package/lib/appborg.js <==
(function() {
  var ABComm, DEFAULT_THEM, DEFAULT_US, EventEmitter, LineStream, decodeLine, encodeLine, _ref;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; }, __slice = Array.prototype.slice;
  EventEmitter = require('events').EventEmitter;
  LineStream = require('linestream');
  _ref = require('./util'), encodeLine = _ref.encodeLine, decodeLine = _ref.decodeLine;
  DEFAULT_US = "subprocess";
  DEFAULT_THEM = "js";
  ABComm = (function() {
    __extends(ABComm, EventEmitter);
    function ABComm(opt) {
      var ls;
      if (opt == null) {
        opt = {};
      }
      ABComm.__super__.constructor.call(this);
      this.output = opt.output || process.stdout;
      if (opt.input) {
        this.input = opt.input;
      } else {
        process.stdin.resume();
        this.input = process.stdin;
      }
      this.name = opt.name || DEFAULT_US;
      this.nextId = 1;
      this.callbacks = {};
      ls = new LineStream(this.input);
      ls.on('data', __bind(function(line) {
        return this.pushEvents([decodeLine(line)]);
      }, this));
      ls.on('end', __bind(function(line) {
        return process.exit(0);
      }, this));
      ls.on('error', __bind(function(line) {
        return process.exit(1);
      }, this));
    }
    ABComm.prototype.send = function() {
      var args, callback, dicts, id, info, method, opt, x, _i, _len;
      method = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
      callback = null;
      dicts = [];
      for (_i = 0, _len = args.length; _i < _len; _i++) {
        x = args[_i];
        if ((typeof x) === 'function') {
          callback = x;
        } else {
          dicts.push(x);
        }
      }
      info = {};
      opt = {};
      if (dicts.length === 1) {
        info = dicts[0];
      } else if (dicts.length === 2) {
        opt = dicts[0], info = dicts[1];
      }
      id = this.nextId;
      this.nextId++;
      if (callback) {
        this.callbacks[id] = callback;
      }
      return this._send({
        id: id,
        from: this.name,
        to: opt.to || DEFAULT_THEM,
        method: method,
        info: info
      });
    };
    ABComm.prototype._send = function(event) {
      return this.output.write(encodeLine(event));
    };
    ABComm.prototype._respond = function(e, error, result) {
      var response;
      response = {
        id: e.id,
        from: this.name,
        to: e.from
      };
      if (error) {
        response.error = error;
        response.result = null;
      } else {
        response.error = null;
        response.result = result;
      }
      return this._send(response);
    };
    ABComm.prototype.pushEvents = function(events) {
      var callback, e, error, f, _i, _len, _results;
      _results = [];
      for (_i = 0, _len = events.length; _i < _len; _i++) {
        e = events[_i];
        _results.push((function() {
          var _j, _len2, _ref2, _results2;
          if ((e.result || e.error) && e.id) {
            callback = this.callbacks[e.id];
            if (callback) {
              try {
                callback(e.error || null, e.result || {});
              } catch (exc) {
                1;
              }
            }
            return delete this.callbacks[e.id];
          } else if (e.method) {
            _ref2 = this.listeners(e.method);
            _results2 = [];
            for (_j = 0, _len2 = _ref2.length; _j < _len2; _j++) {
              f = _ref2[_j];
              _results2.push((function() {
                if (f.length < 2) {
                  try {
                    f(e.info);
                    return this._respond(e, null, {});
                  } catch (exc) {
                    error = {
                      message: exc.toString()
                    };
                    return this._respond(e, error, null);
                  }
                } else {
                  return f(e.info, __bind(function(error, result) {
                    if (error == null) {
                      error = null;
                    }
                    if (result == null) {
                      result = {};
                    }
                    return this._respond(e, error, result);
                  }, this));
                }
              }).call(this));
            }
            return _results2;
          }
        }).call(this));
      }
      return _results;
    };
    return ABComm;
  })();
  module.exports = {
    ABComm: ABComm
  };
}).call(this);

==> appborg-0.0.2.tgz: package/lib/appborg.js <==
(function() {
  var ABComm, DEFAULT_THEM, DEFAULT_US, EventEmitter, LineStream, decodeLine, encodeLine, _ref;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; }, __slice = Array.prototype.slice;
  EventEmitter = require('events').EventEmitter;
  LineStream = require('linestream');
  _ref = require('./appborg_util'), encodeLine = _ref.encodeLine, decodeLine = _ref.decodeLine;
  DEFAULT_US = "subprocess";
  DEFAULT_THEM = "js";
  ABComm = (function() {
    __extends(ABComm, EventEmitter);
    function ABComm(opt) {
      var ls;
      if (opt == null) {
        opt = {};
      }
      ABComm.__super__.constructor.call(this);
      this.output = opt.output || process.stdout;
      if (opt.input) {
        this.input = opt.input;
      } else {
        process.stdin.resume();
        this.input = process.stdin;
      }
      this.name = opt.name || DEFAULT_US;
      this.nextId = 1;
      this.callbacks = {};
      ls = new LineStream(this.input);
      ls.on('data', __bind(function(line) {
        return this.pushEvents([decodeLine(line)]);
      }, this));
      ls.on('end', __bind(function(line) {
        return process.exit(0);
      }, this));
      ls.on('error', __bind(function(line) {
        return process.exit(1);
      }, this));
    }
    ABComm.prototype.send = function() {
      var args, callback, dicts, id, info, method, opt, x, _i, _len;
      method = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
      callback = null;
      dicts = [];
      for (_i = 0, _len = args.length; _i < _len; _i++) {
        x = args[_i];
        if ((typeof x) === 'function') {
          callback = x;
        } else {
          dicts.push(x);
        }
      }
      info = {};
      opt = {};
      if (dicts.length === 1) {
        info = dicts[0];
      } else if (dicts.length === 2) {
        opt = dicts[0], info = dicts[1];
      }
      id = this.nextId;
      this.nextId++;
      if (callback) {
        this.callbacks[id] = callback;
      }
      return this._send({
        id: id,
        from: this.name,
        to: opt.to || DEFAULT_THEM,
        method: method,
        info: info
      });
    };
    ABComm.prototype._send = function(event) {
      return this.output.write(encodeLine(event));
    };
    ABComm.prototype._respond = function(e, error, result) {
      var response;
      response = {
        id: e.id,
        from: this.name,
        to: e.from
      };
      if (error) {
        response.error = error;
        response.result = null;
      } else {
        response.error = null;
        response.result = result;
      }
      return this._send(response);
    };
    ABComm.prototype.pushEvents = function(events) {
      var callback, e, error, f, _i, _len, _results;
      _results = [];
      for (_i = 0, _len = events.length; _i < _len; _i++) {
        e = events[_i];
        _results.push((function() {
          var _j, _len2, _ref2, _results2;
          if ((e.result || e.error) && e.id) {
            callback = this.callbacks[e.id];
            if (callback) {
              try {
                callback(e.error || null, e.result || {});
              } catch (exc) {
                1;
              }
            }
            return delete this.callbacks[e.id];
          } else if (e.method) {
            _ref2 = this.listeners(e.method);
            _results2 = [];
            for (_j = 0, _len2 = _ref2.length; _j < _len2; _j++) {
              f = _ref2[_j];
              _results2.push((function() {
                if (f.length < 2) {
                  try {
                    f(e.info);
                    return this._respond(e, null, {});
                  } catch (exc) {
                    error = {
                      message: exc.toString()
                    };
                    return this._respond(e, error, null);
                  }
                } else {
                  return f(e.info, __bind(function(error, result) {
                    if (error == null) {
                      error = null;
                    }
                    if (result == null) {
                      result = {};
                    }
                    return this._respond(e, error, result);
                  }, this));
                }
              }).call(this));
            }
            return _results2;
          }
        }).call(this));
      }
      return _results;
    };
    return ABComm;
  })();
  module.exports = {
    ABComm: ABComm,
    encodeLine: encodeLine,
    decodeLine: decodeLine
  };
}).call(this);
